# Bridge GPT

This repository contains a GPT2 text generation model that can generate text based on the given input text.

## Dependencies

The following dependencies are needed to run the model:

* Python 3.x
* Streamlit 1.19.0
* Tensorflow 2.11.0
* Transformers 4.26.1

The dependencies can be installed by running the following command:
   ```
   pip install -r requirements.txt
   ```

## How to use

To use the model run the following command:
   ```
   streamlit run main.py
   ```
This will start a local Streamlit server, and the app will open in a new tab in your default web browser.